import CanvasComment from 'canvas-comment';

const canvas = new CanvasComment({
  container: '.container',
  image: 'https://cdn-health.zhongan.com/hic/library/resource/613b041f23e187001cab3a3f/diaCLksvKr.png',
});

canvas.on('load', () => {
  document.querySelector('.container').height = canvas.image.height * 500 / canvas.image.width;

  canvas.setData([
    {
      type: 'rect',
      label: '这里不合规',
      coor: [
        [128, 687],
        [617, 722],
      ],
    },
    {
      type: 'rect',
      label: '率表有误',
      coor: [
        [381, 503],
        [669, 531],
      ],
    },
  ]);
  updateList();
});

canvas.on('input', () => {
  updateList();
});

const canvasInput = document.getElementById('canvas-comment-input');

canvasInput.onblur = () => {
  if (!canvas.activeShape) return;

  // 设置canvas文字
  canvas.activeShape.label = canvasInput.value.trim();
  canvas.activeShape.creating = false;
  canvas.update();
  // 重置input状态
  canvasInput.style.display = 'none';
  canvasInput.value = '';
};

canvas.on('add', (e) => {
  const { coor } = canvas.activeShape;
  const [
    [x0, y0],
    [x1, y1],
  ] = coor;
  const point = [e.clientX - (x1 - x0) * canvas.scale, e.clientY];

  // 录入框宽度
  const inputWidth = Math.max(Math.abs(x1 - x0) * canvas.scale, 120);
  canvasInput.style.width = `${inputWidth}px`;
  canvasInput.style.left = `${point[0]}px`;
  canvasInput.style.top = `${point[1]}px`;
  canvasInput.style.display = 'block';
  canvasInput.focus();
});

function updateList() {
  document.getElementById('comment-list').innerHTML = '';
  const df = document.createDocumentFragment();
  canvas.dataset.forEach((item, index) => {
    const li = document.createElement('li');
    li.innerHTML = `${index + 1}.${item.label}`;
    df.appendChild(li);
  });
  document.getElementById('comment-list').appendChild(df);
}

document.getElementById('create-rect').onclick = () => {
  canvas.createType = 'rect';
};

document.getElementById('resize').onclick = () => {
  canvas.fitZoom();
};

document.getElementById('clean').onclick = () => {
  canvas.clean();
  updateList();
};

document.getElementById('readonly').onchange = (e) => {
  canvas.readonly = e.target.checked;
};

document.getElementById('text-color').onchange = (e) => {
  canvas.createLabelFillStyle = e.target.value;
};

document.getElementById('rect-color').onchange = (e) => {
  canvas.createRectStrokeStyle = e.target.value;
};

document.getElementById('save').onclick = () => {
  console.log(canvas.dataset);
};
