import EventBus from './event-bus';
interface CanvasCommentOptions {
    container?: HTMLCanvasElement | string;
    image?: string;
    fillStyle?: string;
    strokeStyle?: string;
}
interface Rect {
    type: string;
    label?: string;
    rectStrokeStyle?: string;
    labelFillStyle?: string;
    labelBackgroundColor?: string;
    coor: any[];
    active?: boolean;
    creating?: boolean;
}
declare type Shape = Rect;
declare type ShapeType = 'rect';
export default class CanvasComment extends EventBus {
    canvas: HTMLCanvasElement;
    ctx: CanvasRenderingContext2D;
    image: HTMLImageElement;
    imageLoaded: boolean;
    imageWidth: number;
    imageHeight: number;
    imageCrossOrigin: string;
    scaleStep: number;
    movePoint: [number, number];
    originPoint: number[];
    lastOriginPoint: number[];
    spaceKeyDown: boolean;
    dataset: Array<Shape>;
    readonly: boolean;
    rectMinWidth: number;
    rectMinHeight: number;
    labelMaxLen: number;
    labelMinWidth: number;
    labelLineHeight: number;
    labelFont: string;
    labelFillStyle: string;
    labelBackgroundColor: string;
    rectStrokeStyle: string;
    createType?: ShapeType;
    createLabelFillStyle: string;
    createRectStrokeStyle: string;
    currentShape: Shape | undefined;
    minDrawSize: number;
    constructor(options: CanvasCommentOptions);
    get ratio(): number;
    get scale(): number;
    get activeShape(): Rect | undefined;
    init(): Promise<void>;
    update(): void;
    loadImage(): Promise<unknown>;
    paintImage(): void;
    setImage(url: string): void;
    setScale(type: boolean): void;
    /**
     * 计算缩放步长
     * @param reset 是否重置
     */
    calcStep(reset?: boolean): void;
    /**
     * 适配背景图
     */
    fitZoom(): void;
    /**
     * 保持缩放中心
     * @param scale nummer
     */
    stayPosition(scale: number): void;
    /**
       * 判断鼠标是否在背景图内部
       * @param e MouseEvent
       * @returns 布尔值
       */
    isInBackground(e: MouseEvent): boolean;
    /**
     * 绘制label
     * @param point 位置
     * @param label 文本
     */
    drawLabel(point: any, shape: any): void;
    drawRect(shape: Shape): void;
    setData(data: Shape[]): void;
    clean(): void;
    undo(): void;
    /**
     * 获取绘制的图片
     */
    getDrawImage(type?: string, quality?: number): string;
    /**
     * 删除指定矩形
     * @param index number
     */
    deleteActiveShape(): void;
    create(type: ShapeType): void;
}
export {};
